# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
from .statement_dictionary import StatementDictionary
import typing
from .computation import Computation
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class FindMappingResponse(UniversalBaseModel):
    success: bool
    statements: StatementDictionary
    mapping: typing.Dict[str, Computation]

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
